# CLI Commands

## pubtools-sign-msg-container-sign
::: mkdocs-click
    :module: pubtools.sign.signers.msgsigner
    :command: msg_container_sign_main
    :prog_name: pubtools-sign-msg-container-sign

## pubtools-sign-cosign-container-sign
::: mkdocs-click
    :module: pubtools.sign.signers.cosignsigner
    :command: cosign_container_sign_main
    :prog_name: pubtools-sign-cosign-container-sign

## pubtools-sign-msg-clear-sign
::: mkdocs-click
    :module: pubtools.sign.signers.msgsigner
    :command: msg_clear_sign_main
    :prog_name: pubtools-sign-msg-clear-sign

## pubtools-sign multi command bundle
::: mkdocs-click
    :module: pubtools.sign.bundle
    :command: cli
    :prog_name: pubtools-sign
